summaryrefslogtreecommitdiffstats
path: root/plugin/plugintest/api.go
diff options
context:
space:
mode:
Diffstat (limited to 'plugin/plugintest/api.go')
-rw-r--r--plugin/plugintest/api.go25
1 files changed, 13 insertions, 12 deletions
diff --git a/plugin/plugintest/api.go b/plugin/plugintest/api.go
index b3df3616f..4e94e17af 100644
--- a/plugin/plugintest/api.go
+++ b/plugin/plugintest/api.go
@@ -1243,13 +1243,13 @@ func (_m *API) GetUsersByUsernames(usernames []string) ([]*model.User, *model.Ap
return r0, r1
}
-// GetUsersInTeam provides a mock function with given fields: teamId, page, perPage
-func (_m *API) GetUsersInTeam(teamId string, page int, perPage int) ([]*model.User, *model.AppError) {
- ret := _m.Called(teamId, page, perPage)
+// GetUsersInChannel provides a mock function with given fields: channelId, sortBy, page, perPage
+func (_m *API) GetUsersInChannel(channelId string, sortBy string, page int, perPage int) ([]*model.User, *model.AppError) {
+ ret := _m.Called(channelId, sortBy, page, perPage)
var r0 []*model.User
- if rf, ok := ret.Get(0).(func(string, int, int) []*model.User); ok {
- r0 = rf(teamId, page, perPage)
+ if rf, ok := ret.Get(0).(func(string, string, int, int) []*model.User); ok {
+ r0 = rf(channelId, sortBy, page, perPage)
} else {
if ret.Get(0) != nil {
r0 = ret.Get(0).([]*model.User)
@@ -1257,8 +1257,9 @@ func (_m *API) GetUsersInTeam(teamId string, page int, perPage int) ([]*model.Us
}
var r1 *model.AppError
- if rf, ok := ret.Get(1).(func(string, int, int) *model.AppError); ok {
- r1 = rf(teamId, page, perPage)
+
+ if rf, ok := ret.Get(1).(func(string, string, int, int) *model.AppError); ok {
+ r1 = rf(channelId, sortBy, page, perPage)
} else {
if ret.Get(1) != nil {
r1 = ret.Get(1).(*model.AppError)
@@ -1268,13 +1269,13 @@ func (_m *API) GetUsersInTeam(teamId string, page int, perPage int) ([]*model.Us
return r0, r1
}
-// GetUsersInChannel provides a mock function with given fields: channelId, page, perPage
-func (_m *API) GetUsersInChannel(channelId string, page int, perPage int) ([]*model.User, *model.AppError) {
- ret := _m.Called(channelId, page, perPage)
+// GetUsersInTeam provides a mock function with given fields: teamId, page, perPage
+func (_m *API) GetUsersInTeam(teamId string, page int, perPage int) ([]*model.User, *model.AppError) {
+ ret := _m.Called(teamId, page, perPage)
var r0 []*model.User
if rf, ok := ret.Get(0).(func(string, int, int) []*model.User); ok {
- r0 = rf(channelId, page, perPage)
+ r0 = rf(teamId, page, perPage)
} else {
if ret.Get(0) != nil {
r0 = ret.Get(0).([]*model.User)
@@ -1283,7 +1284,7 @@ func (_m *API) GetUsersInChannel(channelId string, page int, perPage int) ([]*mo
var r1 *model.AppError
if rf, ok := ret.Get(1).(func(string, int, int) *model.AppError); ok {
- r1 = rf(channelId, page, perPage)
+ r1 = rf(teamId, page, perPage)
} else {
if ret.Get(1) != nil {
r1 = ret.Get(1).(*model.AppError)